// Target: C8051F38x
// Tool chain: KEIL / SDCC / Raisonance
//
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include "compiler_defs.h"
#include "C8051f380_defs.h"
#include <stddef.h>
#include "USB_API.h"

#define INTERRUPT_USBXpress 17

//-----------------------------------------------------------------------------
// Global CONSTANTS
//-----------------------------------------------------------------------------
/*** [BEGIN] USB Descriptor Information [BEGIN] ***/
SEGMENT_VARIABLE(USB_VID, U16, SEG_CODE) = 0x10C4;			// Vendor ID
SEGMENT_VARIABLE(USB_PID, U16, SEG_CODE) = 0xEA61;			// Product ID
SEGMENT_VARIABLE(USB_bcdDevice, U16, SEG_CODE) = 0x0100;    // Device release 1.00
SEGMENT_VARIABLE(USB_MaxPower, U8, SEG_CODE) = 20;      // Max current: 20*2=40 mA
SEGMENT_VARIABLE(USB_PwAttributes, U8, SEG_CODE) = 0x80;    // Bus-powered,
                                                            // no remote wakeup 

SEGMENT_VARIABLE(USB_MfrStr[], U8, SEG_CODE) = // Manufacturer String
{
   0x1A,
   0x03,
   'S',0,
   'i',0,
   'l',0,
   'i',0,
   'c',0,
   'o',0,
   'n',0,
   ' ',0,
   'L',0,
   'a',0,
   'b',0,
   's',0
};
SEGMENT_VARIABLE(USB_ProductStr[], U8, SEG_CODE) = // Product Desc. String
{
   0x10,
   0x03,
   'U',0,
   'S',0,
   'B',0,
   ' ',0,
   'A',0,
   'P',0,
   'I',0
};

SEGMENT_VARIABLE(USB_SerialStr[], U8, SEG_CODE) = // Serial Number String
{
   0x0A,
   0x03,
   '1',0,
   '2',0,
   '3',0,
   '4',0
};

/*** [ END ] USB Descriptor Information [ END ] ***/

SBIT(Led1, SFR_P1, 4);                 	// LED='1' means ON
SBIT(Led2, SFR_P1, 5);
U8 Packet[3] = {0,0,0};     			// Last packet received from host
U8 led_status[2] = {1,1};				// initially both LEDs are on

//-------------------------
// Port_Init
//-------------------------
// Port Initialization
// - Configure the Crossbar and GPIO ports.
//
void Port_Init(void)
{
   P1MDOUT = 0x30;                    	// Port 0 pins 0-3 set high impedence
   P0SKIP =  0xFF;
   P1SKIP =  0xFF;
   P2SKIP =  0xFF;
   P3SKIP =  0x01;
   XBR1   =  0x40;                    	// Enable Crossbar
}

//-----------------------------------------------------------------------------
// Main Routine
//-----------------------------------------------------------------------------
void main(void)
{
   PCA0MD &= ~0x40;                    	// Disable Watchdog timer

//   USB_Clock_Start();                	//  USB clock *before* calling USB_Init
   USB_Init(USB_VID,USB_PID,USB_MfrStr,USB_ProductStr,USB_SerialStr,
            USB_MaxPower,USB_PwAttributes,USB_bcdDevice);

   CLKSEL |= 0x02;
   RSTSRC |= 0x02;

   USB_Int_Enable();

   while (1)
   {  }
}


// Example ISR for USB_API
INTERRUPT(USB_API_TEST_ISR, INTERRUPT_USBXpress)
{
   U8 INTVAL = Get_Interrupt_Source();

   if (INTVAL & RX_COMPLETE)
   {
      	Block_Read(Packet, 3);
		if (Packet[0] == 0)				// receive data
		{
			if (Packet[1] != 0)
			{
				led_status[0] = 1 - led_status[0];
				Led1 = led_status[0];
			}
			if (Packet[2] != 0)
			{
				led_status[1] = 1 - led_status[1];
				Led2 = led_status[1];
			}
		}
		else							// send data
		{
	    	Packet[0] = 0;
			Packet[1] = led_status[0];
			Packet[2] = led_status[1];
			Block_Write(Packet,3);
		}
   }

   if (INTVAL & DEV_SUSPEND)
   {
        USB_Suspend();
   }

   if (INTVAL & DEV_CONFIGURED)
   {
      Port_Init();
   }
}
